import path from 'path'
import { move, mkdir, removeDir } from './helpers/fs-helpers'
import Listr from 'listr'
import { projectInstall } from 'pkg-install'
import { parseArgumentsIntoOptions, promptForMissingOptions, cloneRepo } from './helpers'

const crateDirectoryForNewWidget = ({ directory, widgetName }) => {
  if (directory) {
    mkdir(path.resolve(directory))
  } else {
    mkdir(path.resolve(widgetName))
  }
}
const forkWidget = (options) => {
  if (options.directory) {
    move(path.resolve('financial-widgets', options.widgetCategory, options.widgetName), path.resolve(options.directory))
  } else {
    move(path.resolve('financial-widgets', options.widgetCategory, options.widgetName), path.resolve(options.widgetName))
  }
}

const cleanUnusedCode = () => {
  removeDir(path.resolve('financial-widgets'))
}
const installDependencies = (options) => {
  if (options.directory) {
    return projectInstall({
      cwd: options.directory,
      prefer: 'yarn'
    })
  } 
    return projectInstall({
      cwd: options.widgetName,
      prefer: 'yarn'
    })
  
}
module.exports = async (args) => {
  let options = parseArgumentsIntoOptions(args)
  const tasks = new Listr([
    {
      title: 'Cloning data from main widget Repository',
      task: () => cloneRepo(options)
    }
  ])
  await tasks.run()
  options = await promptForMissingOptions(options)

  console.log(options)
  const tasks2 = new Listr([
    {
      title: 'Creating New Directory',
      task: () => crateDirectoryForNewWidget(options)
    },
    {
      title: 'Forking Widget to new folder',
      task: () => forkWidget(options)
    },
    {
      title: 'Cleaning Extra Code',
      task: () => cleanUnusedCode(options)
    },
    {
      title: 'Installing dependencies',
      task: () => installDependencies(options)

    }
  ])
  tasks2.run()
}
